==> apache-drill-1.21.2-src.tar.gz: apache-drill-1.21.2-src/contrib/format-ltsv/src/main/java/org/apache/drill/exec/store/ltsv/LTSVFormatPluginConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.drill.exec.store.ltsv;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonTypeName;

import org.apache.commons.lang3.StringUtils;
import org.apache.drill.common.PlanStringBuilder;
import org.apache.drill.common.logical.FormatPluginConfig;
import org.apache.drill.shaded.guava.com.google.common.collect.ImmutableList;

import java.util.List;
import java.util.Objects;

@JsonTypeName("ltsv")
public class LTSVFormatPluginConfig implements FormatPluginConfig {
  private static final List<String> DEFAULT_EXTS = ImmutableList.of("ltsv");

  private final List<String> extensions;
  private final String parseMode;
  private final String escapeCharacter;
  private final String kvDelimiter;
  private final String entryDelimiter;
  private final String lineEnding;
  private final String quoteChar;

  @JsonCreator
  public LTSVFormatPluginConfig(@JsonProperty("extensions") List<String> extensions,
                                @JsonProperty("parseMode") String parseMode,
                                @JsonProperty("escapeCharacter") String escapeCharacter,
                                @JsonProperty("kvDelimiter") String kvDelimiter,
                                @JsonProperty("entryDelimiter") String entryDelimiter,
                                @JsonProperty("lineEnding") String lineEnding,
                                @JsonProperty("quoteChar") String quoteChar) {
    this.extensions = extensions == null ? DEFAULT_EXTS : ImmutableList.copyOf(extensions);
    this.escapeCharacter = escapeCharacter;
    this.kvDelimiter = kvDelimiter;
    this.parseMode = StringUtils.isEmpty(parseMode) ? "lenient" : parseMode;
    this.entryDelimiter = entryDelimiter;
    this.lineEnding = lineEnding;
    this.quoteChar = quoteChar;
  }

  @JsonProperty("parseMode")
  public String getParseMode() {
    return parseMode;
  }

  @JsonProperty("escapeCharacter")
  public String getEscapeCharacter() {
    return escapeCharacter;
  }

  @JsonProperty("kvDelimiter")
  public String getKvDelimiter() {
    return kvDelimiter;
  }

  @JsonProperty("entryDelimiter")
  public String getEntryDelimiter() {
    return entryDelimiter;
  }

  @JsonProperty("lineEnding")
  public String getLineEnding() {
    return lineEnding;
  }

  @JsonProperty("quoteChar")
  public String getQuoteChar() {
    return quoteChar;
  }

  @JsonInclude(JsonInclude.Include.NON_DEFAULT)
  public List<String> getExtensions() {
    return extensions;
  }

  @Override
  public int hashCode() {
    return Objects.hash(extensions,parseMode, escapeCharacter, kvDelimiter, entryDelimiter, lineEnding, quoteChar);
  }

  @Override
  public boolean equals(Object obj) {
    if (this == obj) {
      return true;
    } else if (obj == null || getClass() != obj.getClass()) {
      return false;
    }
    LTSVFormatPluginConfig that = (LTSVFormatPluginConfig) obj;
    return Objects.equals(extensions, that.extensions) &&
        Objects.equals(parseMode, that.parseMode) &&
        Objects.equals(escapeCharacter, that.escapeCharacter) &&
        Objects.equals(entryDelimiter, that.entryDelimiter) &&
        Objects.equals(lineEnding, that.lineEnding) &&
        Objects.equals(quoteChar, that.quoteChar) &&
        Objects.equals(kvDelimiter, that.kvDelimiter);
  }

  @Override
  public String toString() {
    return new PlanStringBuilder(this)
        .field("extensions", extensions)
        .field("parseMode", parseMode)
        .field("escapeCharacter", escapeCharacter)
        .field("kvDelimiter", kvDelimiter)
        .field("lineEnding", lineEnding)
        .field("quoteChar", quoteChar)
        .field("entryDelimiter", entryDelimiter)
        .toString();
  }
}

==> apache-drill-1.22.0-src.tar.gz: apache-drill-1.22.0-src/contrib/format-ltsv/src/main/java/org/apache/drill/exec/store/ltsv/LTSVFormatPluginConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.drill.exec.store.ltsv;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonTypeName;

import org.apache.commons.lang3.StringUtils;
import org.apache.drill.common.PlanStringBuilder;
import org.apache.drill.common.logical.FormatPluginConfig;
import com.google.common.collect.ImmutableList;

import java.util.List;
import java.util.Objects;

@JsonTypeName("ltsv")
public class LTSVFormatPluginConfig implements FormatPluginConfig {
  private static final List<String> DEFAULT_EXTS = ImmutableList.of("ltsv");

  private final List<String> extensions;
  private final String parseMode;
  private final String escapeCharacter;
  private final String kvDelimiter;
  private final String entryDelimiter;
  private final String lineEnding;
  private final String quoteChar;

  @JsonCreator
  public LTSVFormatPluginConfig(@JsonProperty("extensions") List<String> extensions,
                                @JsonProperty("parseMode") String parseMode,
                                @JsonProperty("escapeCharacter") String escapeCharacter,
                                @JsonProperty("kvDelimiter") String kvDelimiter,
                                @JsonProperty("entryDelimiter") String entryDelimiter,
                                @JsonProperty("lineEnding") String lineEnding,
                                @JsonProperty("quoteChar") String quoteChar) {
    this.extensions = extensions == null ? DEFAULT_EXTS : ImmutableList.copyOf(extensions);
    this.escapeCharacter = escapeCharacter;
    this.kvDelimiter = kvDelimiter;
    this.parseMode = StringUtils.isEmpty(parseMode) ? "lenient" : parseMode;
    this.entryDelimiter = entryDelimiter;
    this.lineEnding = lineEnding;
    this.quoteChar = quoteChar;
  }

  @JsonProperty("parseMode")
  public String getParseMode() {
    return parseMode;
  }

  @JsonProperty("escapeCharacter")
  public String getEscapeCharacter() {
    return escapeCharacter;
  }

  @JsonProperty("kvDelimiter")
  public String getKvDelimiter() {
    return kvDelimiter;
  }

  @JsonProperty("entryDelimiter")
  public String getEntryDelimiter() {
    return entryDelimiter;
  }

  @JsonProperty("lineEnding")
  public String getLineEnding() {
    return lineEnding;
  }

  @JsonProperty("quoteChar")
  public String getQuoteChar() {
    return quoteChar;
  }

  @JsonInclude(JsonInclude.Include.NON_DEFAULT)
  public List<String> getExtensions() {
    return extensions;
  }

  @Override
  public int hashCode() {
    return Objects.hash(extensions,parseMode, escapeCharacter, kvDelimiter, entryDelimiter, lineEnding, quoteChar);
  }

  @Override
  public boolean equals(Object obj) {
    if (this == obj) {
      return true;
    } else if (obj == null || getClass() != obj.getClass()) {
      return false;
    }
    LTSVFormatPluginConfig that = (LTSVFormatPluginConfig) obj;
    return Objects.equals(extensions, that.extensions) &&
        Objects.equals(parseMode, that.parseMode) &&
        Objects.equals(escapeCharacter, that.escapeCharacter) &&
        Objects.equals(entryDelimiter, that.entryDelimiter) &&
        Objects.equals(lineEnding, that.lineEnding) &&
        Objects.equals(quoteChar, that.quoteChar) &&
        Objects.equals(kvDelimiter, that.kvDelimiter);
  }

  @Override
  public String toString() {
    return new PlanStringBuilder(this)
        .field("extensions", extensions)
        .field("parseMode", parseMode)
        .field("escapeCharacter", escapeCharacter)
        .field("kvDelimiter", kvDelimiter)
        .field("lineEnding", lineEnding)
        .field("quoteChar", quoteChar)
        .field("entryDelimiter", entryDelimiter)
        .toString();
  }
}
